Learn R Programming

countgmifs (version 0.0.2)

coef.countgmifs: Extract Model Coefficients.

Description

A generic function which extracts the model coefficients from a fitted model object fit using countgmifs

Usage

# S3 method for countgmifs
coef(object, model.select = "BIC", ...)

Arguments

object

an countgmifs fitted object.

model.select

when x is specified any model along the solution path can be selected. The default is model.select="BIC" which calculates the predicted values using the coefficients from the model having the lowest BIC. Other options are model.select="AIC" or any numeric value from the solution path.

...

other arguments.

See Also

See Also countgmifs, predict.countgmifs, summary.countgmifs, plot.countgmifs