Learn R Programming

countgmifs (version 0.0.2)

countgmifs-internal: Functions Called by countgmifs Functions, Not by the User

Description

These functions are called my other countgmifs functions and are not intended to be directly called by the user.

Arguments

Details

The nb.theta and poisson.theta functions for the negative binomial and poisson regression models, respectively, are the log-likelihood functions and are used to estimate the intercept non-penalized subset parameters (if included) at each step of the algorithm. The hilbe function Hilbes estimate of the alpha parameter for the negative binomial regression model.

See Also

See Also as countgmifs