This function returns a numeric vector that is the predicted response from the countgmifs fitted object.
# S3 method for countgmifs
predict(object, neww = NULL, newdata, newx = NULL,
model.select = "BIC", newoffset=NULL, ...)an ordinalgmifs fitted object.
an optional formula that includes the unpenalized variables to use for predicting the response. If omitted, the training data are used.
an optional data.frame that minimally includes the unpenalized variables to use for predicting the response. If omitted, the training data are used.
an optional matrix of penalized variables to use for predicting the response. If omitted, the training data are used.
when x is specified any model along the solution path can be selected. The default is model.select="BIC" which calculates the predicted values using the coefficients from the model having the lowest BIC. Other options are model.select="AIC" or any numeric value from the solution path.
If an offset is used in the fit, then one must be supplied for making predictions.
other arguments.
See Also countgmifs, coef.countgmifs, summary.countgmifs, plot.countgmifs