A generic function which extracts the model coefficients from a fitted model object fit using countgmifs
# S3 method for countgmifs
coef(object, model.select = "BIC", ...)an countgmifs fitted object.
when x is specified any model along the solution path can be selected. The default is model.select="BIC" which calculates the predicted values using the coefficients from the model having the lowest BIC. Other options are model.select="AIC" or any numeric value from the solution path.
other arguments.
See Also countgmifs, predict.countgmifs, summary.countgmifs, plot.countgmifs