This package provides a function that fits a Poisson or negative binomial model when the number of parameters exceeds the sample size, using the the generalized monotone incremental forward stagewise method.
The DESCRIPTION file: countgmifs countgmifs This package contains functions for fitting a penalized discrete response model (either negative binomial or Poisson) and extracting estimated coefficients, predictions, and plots. The model and methods can be used when the response to be predicted is discrete, and is particularly relevant when there are more covariates than observations.
Makowski M., Archer K.J. (2015) Generalized monotone incremental forward stagewise method for modeling count data: application predicting micronuclei frequency. Cancer Informatics, 14(Suppl 2), 97--105.